==> vtigercrm-5.3.0p0.tgz: vtigercrm/modules/Home/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Home/language/en_us.lang.php,v 1.5 2005/03/04 15:18:47 jack Exp $
 * Description:  Defines the English language pack 
 ********************************************************************************/
 
$mod_strings = Array(
'LBL_NEW_FORM_TITLE'=>'New Contact',
'LBL_FIRST_NAME'=>'First Name:',
'LBL_LAST_NAME'=>'Last Name:',
'LBL_LIST_LAST_NAME'=>'Last Name',
'LBL_ACCOUNT_NAME'=>'Account Name:',
'LBL_LIST_ACCOUNT_NAME'=>'Account Name',
'LBL_PHONE'=>'Phone:',
'LBL_EMAIL_ADDRESS'=>'Email:',
'LBL_TOTAL'=>'Total : ',

'LBL_MY_HOME'=>'My Home',
'LBL_MODIFIED_TIME'=>'Modified Time',
'LBL_LOGIN_ID'=>'ID',
'LBL_MODIFIED_BY'=>'Modified By',
'LBL_TYPE'=>'Type',

'LBL_PIPELINE_FORM_TITLE'=>'My Pipeline',

'ERR_ONE_CHAR'=>'Please enter at least one letter or number for your search ...',

'LBL_OPEN_TASKS'=>'My Open Tasks',

'LBL_LEADS_BY_SOURCE'=>'Leads By Source',
'LBL_LEADS_BY_STATUS'=>'Leads By Status',

'LBL_UPCOMING_EVENTS'=>'Upcoming Activities',
'LBL_PENDING_EVENTS'=>'Pending Activities',
'LBL_SINGLE_PENDING_EVENT'=>'Event for Last Ten Days',
'LBL_MULTIPLE_PENDING_EVENTS'=>'Events for Last Ten Days',

'recordsforuser'=>'Records for',

'Today'=>'Today',
'This Week'=>'This Week',
'This Month'=>'This Month',
'This Year'=>'This Year',
'Last Week'=>'Last Week',
'Last 2 Days'=>'Last 2 Days',
'Last Ten Days'=>'Last Ten Days',

// Added/Updated for vtiger CRM 5.0.4 
'TITLE_AJAX_CSS_POPUP_CHAT'=>'Ajax Css-Popup chat',
'User List'=>'User List',

// Added after 5.0.4 GA

//ADDED for Home Page Customization
'LBL_HOME_MODULE' => 'Module',
'LBL_HOME_RSS' => 'RSS',
'LBL_HOME_DASHBOARD' => 'Dashboard',
'LBL_HOME_STUFFTITLE'=>'Window Title',
'LBL_HOME_SHOW'=>'Show',
'LBL_HOME_FILTERBY'=>'Filter By',
'LBL_HOME_Fields'=>'Fields To Show <br>(select any two)',
'LBL_HOME_PRESSCTRL'=>'(Press "Ctrl" <br> for multiple selection)',
'LBL_HOME_RSSURL'=>'RSS URL',
'LBL_HOME_DASHBOARD_NAME'=>'DashBoard Name', 
'LBL_HOME_DASHBOARD_TYPE'=>'DashBoard Type',
'LBL_HOME_HORIZONTAL_BARCHART'=>'Horizontal Bar Chart',
'LBL_HOME_VERTICAL_BARCHART'=>'Vertical Bar Chart',
'LBL_HOME_PIE_CHART'=>'Pie Chart',
'LBL_HOME_ITEMS'=>'item(s)',
'LBL_MORE'=>'More',
'LBL_SCROLL'=>'Scroll',

// vtiger CRM News
'LBL_NEWS_NO'=>'No news',

//added for home page changes
'LBL_NOTEBOOK'=>'Notebook',
'LBL_NOTEBOOK_TITLE'=>'Double-click to edit.',
'LBL_NOTEBOOK_SAVE_TITLE'=>'Click anywhere else on the page to save.',

'LBL_URL'=>'Website',
'LBL_HOME_LAYOUT'=>'Change layout',
'LBL_NUMBER_OF_COLUMNS'=>'Number of columns',
'LBL_TWO_COLUMN'=>'Two Columns',
'LBL_THREE_COLUMN'=>'Three Columns',
'LBL_FOUR_COLUMN'=>'Four Columns',
// END

// Default home page widget's title
'Top Accounts'=>'Top Accounts',
'Top Potentials'=>'Top Potentials',
'Top Quotes'=>'Top Quotes',
'Top Trouble Tickets'=>'Top Trouble Tickets',
'Top Invoices'=>'Top Invoices',
'Top Sales Orders'=>'Top Sales Orders',
'Top Purchase Orders'=>'Top Purchase Orders',
'My New Leads'=>'My New Leads',
'Key Metrics'=>'Key Metrics',
'My Group Allocation'=>'My Group Allocation',
'My Recent FAQs'=>'My Recent FAQs',
'Upcoming Activities'=>'Upcoming Activities',
'Pending Activities'=>'Pending Activities',
'Home Page Dashboard'=>'Home Page Dashboard',
'Tag Cloud'=>'Tag Cloud',

'MSG_NO_FILTERS' => 'No Filters Available',
'MSG_NO_FIELDS' => 'No Fields Available',

);

?>

==> vtigercrm-5.4.0.tgz: vtigercrm/modules/Home/language/en_us.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Home/language/en_us.lang.php,v 1.5 2005/03/04 15:18:47 jack Exp $
 * Description:  Defines the English language pack for Home Module.
 ********************************************************************************/
 
$mod_strings = Array(
'LBL_NEW_FORM_TITLE'=>'New Contact',
'LBL_FIRST_NAME'=>'First Name:',
'LBL_LAST_NAME'=>'Last Name:',
'LBL_LIST_LAST_NAME'=>'Last Name',
'LBL_ACCOUNT_NAME'=>'Organization Name:',
'LBL_LIST_ACCOUNT_NAME'=>'Organization Name',
'LBL_PHONE'=>'Phone:',
'LBL_EMAIL_ADDRESS'=>'Email:',
'LBL_TOTAL'=>'Total : ',

'LBL_MY_HOME'=>'My Home',
'LBL_MODIFIED_TIME'=>'Modified Time',
'LBL_LOGIN_ID'=>'ID',
'LBL_MODIFIED_BY'=>'Modified By',
'LBL_TYPE'=>'Type',

'LBL_PIPELINE_FORM_TITLE'=>'My Pipeline',

'ERR_ONE_CHAR'=>'Please enter at least one letter or number for your search ...',

'LBL_OPEN_TASKS'=>'My Open Tasks',

'LBL_LEADS_BY_SOURCE'=>'Leads By Source',
'LBL_LEADS_BY_STATUS'=>'Leads By Status',

'LBL_UPCOMING_EVENTS'=>'Upcoming Activities',
'LBL_PENDING_EVENTS'=>'Pending Activities',
'LBL_SINGLE_PENDING_EVENT'=>'Event for Last Ten Days',
'LBL_MULTIPLE_PENDING_EVENTS'=>'Events for Last Ten Days',

'recordsforuser'=>'Records for',

'Today'=>'Today',
'This Week'=>'This Week',
'This Month'=>'This Month',
'This Year'=>'This Year',
'Last Week'=>'Last Week',
'Last 2 Days'=>'Last 2 Days',
'Last Ten Days'=>'Last Ten Days',

// Added/Updated for vtiger CRM 5.0.4 
'TITLE_AJAX_CSS_POPUP_CHAT'=>'Ajax Css-Popup chat',
'User List'=>'User List',

// Added after 5.0.4 GA

//ADDED for Home Page Customization
'LBL_HOME_MODULE' => 'Module',
'LBL_HOME_RSS' => 'RSS',
'LBL_HOME_DASHBOARD' => 'Dashboard',
'LBL_HOME_STUFFTITLE'=>'Window Title',
'LBL_HOME_SHOW'=>'Show',
'LBL_HOME_FILTERBY'=>'Filter By',
'LBL_HOME_Fields'=>'Fields To Show <br>(select any two)',
'LBL_HOME_PRESSCTRL'=>'(Press "Ctrl" <br> for multiple selection)',
'LBL_HOME_RSSURL'=>'RSS URL',
'LBL_HOME_DASHBOARD_NAME'=>'DashBoard Name', 
'LBL_HOME_DASHBOARD_TYPE'=>'DashBoard Type',
'LBL_HOME_HORIZONTAL_BARCHART'=>'Horizontal Bar Chart',
'LBL_HOME_VERTICAL_BARCHART'=>'Vertical Bar Chart',
'LBL_HOME_PIE_CHART'=>'Pie Chart',
'LBL_HOME_ITEMS'=>'item(s)',
'LBL_MORE'=>'More',
'LBL_SCROLL'=>'Scroll',

// vtiger CRM News
'LBL_NEWS_NO'=>'No news',

//added for home page changes
'LBL_NOTEBOOK'=>'Notebook',
'LBL_NOTEBOOK_TITLE'=>'Double-click to edit.',
'LBL_NOTEBOOK_SAVE_TITLE'=>'Click anywhere else on the page to save.',

'LBL_URL'=>'Website',
'LBL_HOME_LAYOUT'=>'Change layout',
'LBL_NUMBER_OF_COLUMNS'=>'Number of columns',
'LBL_TWO_COLUMN'=>'Two Columns',
'LBL_THREE_COLUMN'=>'Three Columns',
'LBL_FOUR_COLUMN'=>'Four Columns',
// END

// Default home page widget's title
'Top Accounts'=>'Top Organizations',
'Top Potentials'=>'Top Opportunities',
'Top Quotes'=>'Top Quotes',
'Top Trouble Tickets'=>'Top Trouble Tickets',
'Top Invoices'=>'Top Invoices',
'Top Sales Orders'=>'Top Sales Orders',
'Top Purchase Orders'=>'Top Purchase Orders',
'My New Leads'=>'My New Leads',
'Key Metrics'=>'Key Metrics',
'My Group Allocation'=>'My Group Allocation',
'My Recent FAQs'=>'My Recent FAQs',
'Upcoming Activities'=>'Upcoming Activities',
'Pending Activities'=>'Pending Activities',
'Home Page Dashboard'=>'Home Page Dashboard',
'Tag Cloud'=>'Tag Cloud',

'MSG_NO_FILTERS' => 'No Filters Available',
'MSG_NO_FIELDS' => 'No Fields Available',

//Customization Phase 6 -- Monolithic
'LBL_REPORTCHARTS' => 'ReportCharts',
'LBL_HOME_REPORT_NAME'=> 'Report Name',
'LBL_HOME_REPORT_TYPE' => 'Report Type',
//END

//added for Default Widgets
'LBL_DEFAULT_WIDGET'=>'Default Widgets',
'LBL_NO_WIDGETS_HIDDEN'=>'No default widgets are hidden',
);

?>
